[xorg-commit-diffs] xc/programs/Xserver/hw/darwin/quartz/xpr xprScreen.c, 1.1.4.4, 1.1.4.5

Egbert Eich xorg-commit at pdx.freedesktop.org
Thu Apr 15 03:16:01 PDT 2004


Committed by: eich

Update of /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz/xpr
In directory pdx:/home/eich/tstbuild/xc/programs/Xserver/hw/darwin/quartz/xpr

Modified Files:
      Tag: XORG-CURRENT
	xprScreen.c 
Log Message:
2004-04-15  Egbert Eich  <eich at freedesktop.org>
        Merged changes from RELEASE-1 branch
	


Index: xprScreen.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz/xpr/xprScreen.c,v
retrieving revision 1.1.4.4
retrieving revision 1.1.4.5
diff -u -d -r1.1.4.4 -r1.1.4.5
--- a/xprScreen.c	5 Mar 2004 13:40:00 -0000	1.1.4.4
+++ b/xprScreen.c	15 Apr 2004 10:15:56 -0000	1.1.4.5
@@ -33,7 +33,7 @@
 #include "quartzCommon.h"
 #include "quartz.h"
 #include "xpr.h"
-#include "pseudorama.h"
+#include "pseudoramiX.h"
 #include "darwin.h"
 #include "rootless.h"
 #include "safeAlpha.h"
@@ -139,8 +139,8 @@
 
 
 /*
- * addPseudoramaScreens
- *  Add a physical screen with Pseudorama.
+ * addPseudoramiXScreens
+ *  Add a physical screen with PseudoramiX.
  */
 static void
 addPseudoramiXScreens(int *x, int *y, int *width, int *height)
@@ -168,21 +168,21 @@
     *width = unionRect.size.width;
     *height = unionRect.size.height;
 
     /* Tell Pseudorama about the real screens. */
     for (i = 0; i < displayCount; i++)
     {
         CGDirectDisplayID dpy = displayList[i];
 
         frame = displayScreenBounds(dpy);
 
-        ErrorF("Pseudorama screen %d added: %dx%d @ (%d,%d).\n", i,
+        ErrorF("PseudoramiX screen %d added: %dx%d @ (%d,%d).\n", i,
                (int)frame.size.width, (int)frame.size.height,
                (int)frame.origin.x, (int)frame.origin.y);
 
         frame.origin.x -= unionRect.origin.x;
         frame.origin.y -= unionRect.origin.y;
 
-        ErrorF("Pseudorama screen %d placed at X11 coordinate (%d,%d).\n",
+        ErrorF("PseudoramiX screen %d placed at X11 coordinate (%d,%d).\n",
                i, (int)frame.origin.x, (int)frame.origin.y);
 
         PseudoramiXAddScreen(frame.origin.x, frame.origin.y,
@@ -206,7 +206,7 @@
 
     CGGetActiveDisplayList(0, NULL, &displayCount);
 
     /* With Pseudorama, the X server only sees one screen; only Pseudorama
        itself knows about all of the screens. */
 
     if (noPseudoramiXExtension)
@@ -168,21 +168,21 @@
     *height = unionRect.size.height;
 
-    /* Tell Pseudorama about the real screens. */
+    /* Tell PseudoramiX about the real screens. */
     for (i = 0; i < displayCount; i++)
     {
@@ -206,7 +206,7 @@
     CGGetActiveDisplayList(0, NULL, &displayCount);
 
-    /* With Pseudorama, the X server only sees one screen; only Pseudorama
+    /* With PseudoramiX, the X server only sees one screen; only PseudoramiX
        itself knows about all of the screens. */
 




More information about the xorg-commit-diffs mailing list